@@ -421,8 +421,6 @@ def generate_timer_unit(job, seq):
         f.write('Description=[Timer] "%s"\n' % job['l'])
         f.write('Documentation=man:systemd-crontab-generator(8)\n')
         f.write('PartOf=cron.target\n')
-        f.write('RefuseManualStart=true\n')
-        f.write('RefuseManualStop=true\n')
         f.write('SourcePath=%s\n' % job['f'])
         if testremoved: f.write('ConditionFileIsExecutable=%s\n' % testremoved)
 
@@ -443,8 +441,6 @@ def generate_timer_unit(job, seq):
         f.write('[Unit]\n')
         f.write('Description=[Cron] "%s"\n' % job['l'])
         f.write('Documentation=man:systemd-crontab-generator(8)\n')
-        f.write('RefuseManualStart=true\n')
-        f.write('RefuseManualStop=true\n')
         f.write('SourcePath=%s\n' % job['f'])
         if '"MAILTO="' in job['e']:
             pass # mails explicitely disabled
@@ -473,7 +469,7 @@ def generate_timer_unit(job, seq):
 def log(level, message):
     if len(sys.argv) == 4:
         with open('/dev/kmsg', 'w', encoding='utf8') as kmsg:
-            kmsg.write('<%s> %s[%s]: %s\n' % (level, SELF, os.getpid(), message))
+            kmsg.write('<%s>%s[%s]: %s\n' % (level, SELF, os.getpid(), message))
     else:
         sys.stderr.write('%s: %s\n' % (SELF, message))
 
@@ -505,21 +501,25 @@ def main():
     CRONTAB_FILES = files('/etc/cron.d')
     for filename in CRONTAB_FILES:
         basename = os.path.basename(filename)
-        if (os.path.exists('@unitdir@/%s.timer' % basename)
-         or os.path.exists('/etc/systemd/system/%s.timer' % basename)):
-            log(5, 'ignoring %s because native timer is present' % filename)
+        for unit_file in ('@unitdir@/%s.timer' % basename,
+                          '/etc/systemd/system/%s.timer' % basename,
+                          '/run/systemd/system/%s.timer' % basename):
+            if os.path.exists(unit_file):
+                if os.path.realpath(unit_file) == '/dev/null':
+                    log(5, 'ignoring %s because it is masked' % filename)
+                else:
+                    log(5, 'ignoring %s because native timer is present' % filename)
+                continue
+        if basename.startswith('.'):
             continue
-        elif basename.startswith('.'):
-            continue
-        elif '.dpkg-' in basename:
+        if '.dpkg-' in basename:
             log(5, 'ignoring %s' % filename)
             continue
-        else:
-            for job in parse_crontab(filename, withuser=True):
-                if 'c' not in job:
-                    log(3, 'truncated line in %s: %s' % (filename, job['l']))
-                    continue
-                generate_timer_unit(job, seqs.setdefault(job['j']+job['u'], count()))
+        for job in parse_crontab(filename, withuser=True):
+            if 'c' not in job:
+                log(3, 'truncated line in %s: %s' % (filename, job['l']))
+                continue
+            generate_timer_unit(job, seqs.setdefault(job['j']+job['u'], count()))
 
     if os.path.isfile('/etc/anacrontab'):
         for job in parse_crontab('/etc/anacrontab', monotonic=True):
